@@ -28,7 +28,7 @@
 /* todo: Eq5p -- 20-400, 60-1k, 150-2.5k, 500-8k, 1k-20k */
 
 #include "basics.h"
-#include <stdio.h>
+#include "dsp/Sine.h"
 
 #include "Eq.h"
 #include "Descriptor.h"
@@ -62,25 +62,22 @@ Eq10::activate()
 {
 	for (int i = 0; i < 10; ++i)
 	{
-		gain[i] = getport (1 + i);
+		gain[i] = getport(i);
 		eq.gain[i] = adjust_gain (i, db2lin (gain[i]));
 		eq.gf[i] = 1;
 	}
 }
 
-template <yield_func_t F>
 void
 Eq10::cycle (uint frames)
 {
-	sample_t * s = ports[0];
-
 	/* evaluate band gain changes and compute recursion factor to prevent
 	 * zipper noise */
 	double one_over_n = frames > 0 ? 1. / frames : 1;
 
 	for (int i = 0; i < 10; ++i)
 	{
-		sample_t g = getport (1 + i);
+		sample_t g = getport(i);
 		if (g == gain[i])
 		{
 			/* no gain factoring */
@@ -93,13 +90,14 @@ Eq10::cycle (uint frames)
 		eq.gf[i] = pow (want / eq.gain[i], one_over_n);
 	}
 
+	sample_t * s = ports[10];
 	sample_t * d = ports[11];
 
 	for (uint i = 0; i < frames; ++i)
 	{
 		sample_t x = s[i];
 		x = eq.process (x);
-		F (d, i, x, adding_gain);
+		d[i] = x;
 	}
 
 	eq.normal = -normal;
@@ -111,8 +109,6 @@ Eq10::cycle (uint frames)
 PortInfo
 Eq10::port_info [] =
 {
-	{"in", INPUT | AUDIO, {0, -1, 1}}, 
-
 	{"31 Hz", CTRL_IN, {DEFAULT_0, -48, 24}}, 
 	{"63 Hz", CTRL_IN, {DEFAULT_0, -48, 24}}, 
 	{"125 Hz", CTRL_IN | GROUP, {DEFAULT_0, -48, 24}}, 
@@ -124,7 +120,8 @@ Eq10::port_info [] =
 	{"8 kHz", CTRL_IN | GROUP, {DEFAULT_0, -48, 24}}, 
 	{"16 kHz", CTRL_IN, {DEFAULT_0, -48, 24}}, 
 
-	{"out", OUTPUT | AUDIO, {0}}
+	{"in", INPUT | AUDIO}, 
+	{"out", OUTPUT | AUDIO}
 };
 
 template <> void
@@ -157,7 +154,7 @@ Eq10X2::activate()
 	 */
 	for (int i = 0; i < 10; ++i)
 	{
-		gain[i] = getport (2 + i);
+		gain[i] = getport(i);
 		double a = adjust_gain (i, db2lin (gain[i]));
 		for (int c = 0; c < 2; ++c)
 			eq[c].gf[i] = 1,
@@ -165,7 +162,6 @@ Eq10X2::activate()
 	}
 }
 
-template <yield_func_t F>
 void
 Eq10X2::cycle (uint frames)
 {
@@ -177,12 +173,12 @@ Eq10X2::cycle (uint frames)
 	{
 		double a;
 
-		if (*ports [2 + i] == gain[i])
+		if (*ports[i] == gain[i])
 			/* still same value, no gain fade */
 			a = 1;
 		else
 		{
-			gain[i] = getport (2 + i);
+			gain[i] = getport(i);
 			
 			/* prepare factor for logarithmic gain fade */
 			a = adjust_gain (i, db2lin (gain[i]));
@@ -196,14 +192,14 @@ Eq10X2::cycle (uint frames)
 	for (int c = 0; c < 2; ++c)
 	{
 		sample_t 
-			* s = ports[c],
+			* s = ports[10 + c],
 			* d = ports[12 + c];
 
 		for (uint i = 0; i < frames; ++i)
 		{
 			sample_t x = s[i];
 			x = eq[c].process (x);
-			F (d, i, x, adding_gain);
+			d[i] = x;
 		}
 	}
 
@@ -218,9 +214,6 @@ Eq10X2::cycle (uint frames)
 PortInfo
 Eq10X2::port_info [] =
 {
-	{"in.l", INPUT | AUDIO, {0, -1, 1}}, 
-	{"in.r", INPUT | AUDIO, {0, -1, 1}}, 
-
 	{"31 Hz", CTRL_IN, {DEFAULT_0, -48, 24}}, 
 	{"63 Hz", CTRL_IN, {DEFAULT_0, -48, 24}}, 
 	{"125 Hz", CTRL_IN | GROUP, {DEFAULT_0, -48, 24}}, 
@@ -232,8 +225,10 @@ Eq10X2::port_info [] =
 	{"8 kHz", CTRL_IN | GROUP, {DEFAULT_0, -48, 24}}, 
 	{"16 kHz", CTRL_IN, {DEFAULT_0, -48, 24}}, 
 
-	{"out.l", OUTPUT | AUDIO, {0}}, 
-	{"out.r", OUTPUT | AUDIO, {0}}
+	{"in.l", INPUT | AUDIO}, 
+	{"in.r", INPUT | AUDIO}, 
+	{"out.l", OUTPUT | AUDIO}, 
+	{"out.r", OUTPUT | AUDIO}
 };
 
 template <> void
@@ -274,7 +269,7 @@ Eq4p::activate()
 	xfade = false;
 }
 
-typedef struct {sample_t a[3], b[3];} BiQuad_ab;
+typedef struct {sample_t a[3], b[3];} IIR2_ab;
 
 void
 Eq4p::updatestate()
@@ -296,7 +291,7 @@ Eq4p::updatestate()
 		state[i].f = f;
 		state[i].gain = gain;
 
-		BiQuad_ab c; 
+		IIR2_ab c; 
 
 		f *= over_fs;
 		/* Zoelzer shelve: H(s) = (A*s^2 + s*(sqrt(A)/Q) + 1) / (s^2 + s/Q + 1) */
@@ -315,12 +310,13 @@ Eq4p::updatestate()
 	}
 }
 
-template <yield_func_t yield>
 void
 Eq4p::cycle (uint frames)
 {
-	sample_t * s = ports[16];
-	sample_t * d = ports[17];
+	*ports[16] = 3; /* _latency */
+
+	sample_t * s = ports[17];
+	sample_t * d = ports[18];
 
 	updatestate(); 
 
@@ -330,19 +326,21 @@ Eq4p::cycle (uint frames)
 		{
 			sample_t x = s[i] + normal;
 			x = filter[0].seriesprocess(x);
-			yield (d,i, x, adding_gain);
+			d[i] = x;
 		}
 	}
 	else
 	{
-		/* simple linear crossfade */
-		sample_t g0=1, g1=0, dg=1./frames;
+		float over_n = frames ? 1./frames : 1;
+		DSP::Sine gf0 (.5*M_PI*over_n,.5*M_PI);
+		DSP::Sine gf1 (.5*M_PI*over_n,0);
 		for (uint i = 0; i < frames; ++i)
 		{
-			sample_t x = s[i] + normal;
-			x = g0*filter[0].seriesprocess(x) + g1*filter[1].seriesprocess(x);
-			yield (d,i, x, adding_gain);
-			g0 -= dg, g1 += dg;
+			sample_t x = s[i];
+			sample_t g0 = gf0.get();
+			sample_t g1 = gf1.get();
+			x = g0*g0*filter[0].seriesprocess(x) + g1*g1*filter[1].seriesprocess(x);
+			d[i] = x;
 		}
 		
 		filter[0] = filter[1];
@@ -382,6 +380,9 @@ Eq4p::port_info [] =
 	{"d.gain (dB)", CTRL_IN, {DEFAULT_0, -48, 24}},
 
 	/* 16 */
+	{"_latency", OUTPUT|CONTROL|GROUP, {INTEGER|DEFAULT_MAX,3,3}, "{3:'3 samples'}"},
+
+	/* 17 */
 	{"in", INPUT | AUDIO, {0, -1, 1}}, 
 	{"out", OUTPUT | AUDIO, {0}}
 };
@@ -391,11 +392,164 @@ Descriptor<Eq4p>::setup()
 {
 	Label = "Eq4p";
 
-	Name = CAPS "Eq4p - 4-band parametric equaliser";
+	Name = CAPS "Eq4p - 4-band parametric shelving equaliser";
 	Maker = "Tim Goetze <tim@quitte.de>";
-	Copyright = "2013";
+	Copyright = "2013-14";
 
 	/* fill port info and vtable */
 	autogen();
 }
 
+/* //////////////////////////////////////////////////////////////////////// */
+
+void
+EqFA4p::init()
+{
+	/* limit filter frequency to slightly under Nyquist to be on the safe side */
+	float limit = .48*fs; 
+	for (int i = 0; i < 4; ++i)
+	{
+		state[i].f = -1; /* ensure all coefficients updated */
+		ranges[4*i + 1].UpperBound = min(ranges[4*i + 1].UpperBound, limit);
+	}
+}
+
+void
+EqFA4p::activate()
+{
+	filter[0].reset();
+	filter[1].reset();
+
+	updatestate();
+	filter[0] = filter[1];
+	xfade = false;
+	gain = db2lin(getport(16));
+}
+
+void
+EqFA4p::updatestate()
+{
+	for (int i=0; i<4; ++i)
+	{
+		sample_t mode = getport(i*4 + 0);
+		sample_t f = getport(i*4 + 1);
+		sample_t bw = getport(i*4 + 2);
+		sample_t gain = getport(i*4 + 3);
+
+		if (mode==state[i].mode && gain==state[i].gain && f==state[i].f && bw==state[i].bw) 
+			continue;
+
+		xfade = true;
+
+		state[i].mode = mode;
+		state[i].bw = bw;
+		state[i].f = f;
+		state[i].gain = gain;
+
+		if (!mode)
+			filter[1].unity(i);
+		else
+			filter[1].set(i, f*over_fs, bw, db2lin(gain));
+	}
+}
+
+void
+EqFA4p::cycle (uint frames)
+{
+	updatestate(); 
+
+	sample_t g = db2lin(getport(16));
+	sample_t over_n = frames ? 1./frames : 1;
+	sample_t gf = pow(g/gain, over_n);
+
+	*ports[17] = 3; /* _latency */
+	sample_t * s = ports[18];
+	sample_t * d = ports[19];
+
+	if (!xfade)
+	{
+		for (uint i = 0; i < frames; ++i)
+		{
+			sample_t x = s[i];
+			x = filter[0].seriesprocess(x);
+			x = gain*x;
+			gain *= gf;
+			d[i] = x;
+		}
+	}
+	else
+	{
+		DSP::Sine gf0 (.5*M_PI*over_n,.5*M_PI);
+		DSP::Sine gf1 (.5*M_PI*over_n,0);
+		for (uint i = 0; i < frames; ++i)
+		{
+			sample_t x = s[i];
+			sample_t g0 = gf0.get();
+			sample_t g1 = gf1.get();
+			x = g0*g0*filter[0].seriesprocess(x) + g1*g1*filter[1].seriesprocess(x);
+			x = gain*x;
+			gain *= gf;
+			d[i] = x;
+		}
+		
+		filter[0] = filter[1];
+		filter[1].reset();
+		xfade = false;
+	}
+}
+
+/* //////////////////////////////////////////////////////////////////////// */
+
+static const char * EqFA4pBandModes = "{0:'off',1:'on'}";
+
+PortInfo
+EqFA4p::port_info [] =
+{
+	{"a.act", CTRL_IN | GROUP, {DEFAULT_0 | INTEGER, 0,1}, EqFA4pBandModes},
+	{"a.f (Hz)", CTRL_IN, {DEFAULT_LOW | LOG, 20, 14000}},
+	{"a.bw", CTRL_IN, {DEFAULT_1, .125, 8}},
+	{"a.gain (dB)", CTRL_IN, {DEFAULT_0, -24, 24}},
+
+	/* 4 */
+	{"b.act", CTRL_IN | GROUP, {DEFAULT_0 | INTEGER, 0,1}, EqFA4pBandModes},
+	{"b.f (Hz)", CTRL_IN, {DEFAULT_MID | LOG, 20, 14000}},
+	{"b.bw", CTRL_IN, {DEFAULT_1, .125, 8}},
+	{"b.gain (dB)", CTRL_IN, {DEFAULT_0, -24, 24}},
+
+	/* 8 */
+	{"c.act", CTRL_IN | GROUP, {DEFAULT_0 | INTEGER, 0,1}, EqFA4pBandModes},
+	{"c.f (Hz)", CTRL_IN, {DEFAULT_MID | LOG, 20, 14000}},
+	{"c.bw", CTRL_IN, {DEFAULT_1, .125, 8}},
+	{"c.gain (dB)", CTRL_IN, {DEFAULT_0, -24, 24}},
+
+	/* 12 */
+	{"d.act", CTRL_IN | GROUP, {DEFAULT_0 | INTEGER, 0,1}, EqFA4pBandModes},
+	{"d.f (Hz)", CTRL_IN, {DEFAULT_HIGH | LOG, 20, 14000}},
+	{"d.bw", CTRL_IN, {DEFAULT_1, .125, 8}},
+	{"d.gain (dB)", CTRL_IN, {DEFAULT_0, -24, 24}},
+
+	/* 16 */
+	{"gain", CTRL_IN|GROUP, {DEFAULT_0, -24, 24}},
+
+	/* 17 */
+	{"_latency", OUTPUT|CONTROL|GROUP, {INTEGER|DEFAULT_MAX,3,3}, "{3:'3 samples'}"},
+
+	/* 18 */
+	{"in", INPUT | AUDIO}, 
+	{"out", OUTPUT | AUDIO}
+};
+
+template <> void
+Descriptor<EqFA4p>::setup()
+{
+	Label = "EqFA4p";
+
+	Name = CAPS "EqFA4p - 4-band parametric eq";
+	Maker = "Tim Goetze <tim@quitte.de>";
+	Copyright = "2014";
+
+	/* fill port info and vtable */
+	autogen();
+}
+
+
