@@ -29,18 +29,15 @@
 
 #include "basics.h"
 #include "dsp/util.h"
+#include "dsp/Sine.h"
 
 #include "ToneStack.h"
 #include "Descriptor.h"
 
-#include "dsp/tonestack/ks_tab.h"
-#include "dsp/tonestack/vs_tab.h"
-
 const char *
 DSP::ToneStack::presetdict =
-		"{0:'basswoman', 1:'twin', 2:'wookie', 3:'DC 30', 4:'juice 800',"
-		"5:'stanford', 6:'AK 20', 7:'nihon ace', 8:'porky',"
-		"9:'5F6-A LT'}";
+		"{0:'basswoman', 1:'stanford', 2:'wookie', 3:'DC 30', 4:'juice 800',"
+		"5:'twin', 6:'AK 20', 7:'nihon ace', 8:'porky',}";
 
 DSP::TSParameters 
 DSP::ToneStack::presets[] = {
@@ -53,13 +50,13 @@ DSP::ToneStack::presets[] = {
 	/* R1=treble R2=Bass R3=Mid, C1-3 related caps, R4 = parallel resistor */
 	/* { 250000, 1000000, 25000, 56000, 0.25e-9, 20e-9, 20e-9 }, DY */
 	{250 k, 1 M, 25 k, 56 k, 250 pF, 20 nF, 20 nF},  /* 59 Bassman 5F6-A */
-	{250 k, 250 k, 10 k, 100 k, 120 pF, 100 nF, 47 nF}, /* 69 Twin Reverb AA270 */
+	{250 k, 250 k, 4.8 k, 100 k, 250 pF, 100 nF, 47 nF}, /* 64 Princeton AA1164 */
 	{250 k, 1 M, 25 k, 47 k, 600 pF, 20 nF, 20 nF}, /* Mesa Dual Rect. 'Orange' */
 	/* Vox -- R3 is fixed (circuit differs anyway) */
-	{1 M, 1 M, 10 k, 100 k, 50 pF, 22 nF, 22 nF}, /* 59/86 Vox AC-30 */
+	{1 M, 1 M, 20 k, 100 k, 50 pF, 22 nF, 22 nF}, /* 59/86 Vox AC-30 */
 	
 	{220 k, 1 M, 22 k, 33 k, 470 pF, 22 nF, 22 nF}, /* 59/81 JCM-800 Lead 100 2203 */
-	{250 k, 250 k, 4.8 k, 100 k, 250 pF, 100 nF, 47 nF}, /* 64 Princeton AA1164 */
+	{250 k, 250 k, 10 k, 100 k, 120 pF, 100 nF, 47 nF}, /* 69 Twin Reverb AA270 */
 
 	{500 k, 1 M, 25 k, 47 k, 150 pF, 22 nF, 22 nF}, /* Hughes & Kettner Tube 20 */
 	{250 k, 250 k, 10 k, 100 k, 150 pF, 82 nF, 47 nF}, /* Roland Jazz Chorus */
@@ -83,20 +80,15 @@ ToneStack::activate()
 	model = -1;
 }
 
-template <yield_func_t F>
 void
 ToneStack::cycle (uint frames)
 {
-	static int LTModel = port_info[0].range.UpperBound;
 	int m = getport(0);
 	
 	if (m != model)
 	{
 		model = m;
-		if (model == LTModel) 
-			tonestacklt.reset();
-		else 
-			tonestack.setmodel (model);
+		tonestack.setmodel (model);
 	}
 
 	sample_t * s = ports[4];
@@ -104,25 +96,11 @@ ToneStack::cycle (uint frames)
 
 	float bass=getport(1), mid=getport(2), treble=getport(3);
 
-	if (model == LTModel) 
+	tonestack.updatecoefs (bass, mid, treble);
+	for (uint i = 0; i < frames; ++i) 
 	{
-		tonestacklt.updatecoefs (bass, mid, treble);
-		for (uint i = 0; i < frames; ++i) 
-		{
-			sample_t a = s[i];
-			a = tonestacklt.process (a + normal);
-			F (d, i, a, adding_gain);
-		}
-	} 
-	else 
-	{
-		tonestack.updatecoefs (bass, mid, treble);
-		for (uint i = 0; i < frames; ++i) 
-		{
-			sample_t a = s[i];
-			a = tonestack.process (a + normal);
-			F (d, i, a, adding_gain);
-		}
+		sample_t a = s[i];
+		d[i] = tonestack.process(a + normal);
 	}
 }
 
@@ -130,10 +108,11 @@ ToneStack::cycle (uint frames)
 PortInfo
 ToneStack::port_info [] = 
 {
-	{ "model", CTRL_IN, {DEFAULT_0 | INTEGER, 0, 8+1}, DSP::ToneStack::presetdict }, 
+	{ "model", CTRL_IN, {DEFAULT_0 | INTEGER, 0, 8}, DSP::ToneStack::presetdict }, 
 	{ "bass", CTRL_IN | GROUP, {DEFAULT_MID, 0, 1} }, 
 	{ "mid", CTRL_IN, {DEFAULT_MID, 0, 1} }, 
 	{ "treble", CTRL_IN, {DEFAULT_MID, 0, 1} }, 
+
 	{ "in", INPUT | AUDIO, {BOUNDED, -1, 1} }, 
 	{ "out", OUTPUT | AUDIO }
 };
